@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import unicode_literals, division, absolute_import
-from urllib import quote
-from requests.exceptions import RequestException
 from logging import getLogger
+from urllib import quote
+
+from requests.exceptions import RequestException
+
+from flexget import plugin, validator
+from flexget.event import event
 from flexget.utils import json, requests
-from flexget.plugin import register_plugin, PluginError
-from flexget import validator
 
 log = getLogger('pyload')
 
@@ -52,9 +54,6 @@ class PluginPyLoad(object):
     DEFAULT_PREFERRED_HOSTER_ONLY = False
     DEFAULT_HANDLE_NO_URL_AS_FAILURE = False
 
-    def __init__(self):
-        self.session = None
-
     def validator(self):
         """Return config validator"""
         root = validator.factory()
@@ -72,9 +71,6 @@ class PluginPyLoad(object):
         advanced.accept('boolean', key='handle_no_url_as_failure')
         return root
 
-    def on_process_start(self, task, config):
-        self.session = None
-
     def on_task_output(self, task, config):
         if not config.get('enabled', True):
             return
@@ -87,13 +83,13 @@ class PluginPyLoad(object):
         """Adds accepted entries"""
 
         try:
-            self.check_login(task, config)
+            session = self.get_session(config)
         except IOError:
-            raise PluginError('pyLoad not reachable', log)
-        except PluginError:
+            raise plugin.PluginError('pyLoad not reachable', log)
+        except plugin.PluginError:
             raise
         except Exception as e:
-            raise PluginError('Unknown error: %s' % str(e), log)
+            raise plugin.PluginError('Unknown error: %s' % str(e), log)
 
         api = config.get('api', self.DEFAULT_API)
         hoster = config.get('hoster', self.DEFAULT_HOSTER)
@@ -108,7 +104,7 @@ class PluginPyLoad(object):
 
             log.debug("Parsing url %s" % url)
 
-            result = query_api(api, "parseURLs", {"html": content, "url": url, "session": self.session})
+            result = query_api(api, "parseURLs", {"html": content, "url": url, "session": session})
 
             # parsed { plugins: [urls] }
             parsed = result.json()
@@ -128,7 +124,7 @@ class PluginPyLoad(object):
                     if name != "BasePlugin":
                         urls.extend(purls)
 
-            if task.manager.options.test:
+            if task.options.test:
                 log.info('Would add `%s` to pyload' % urls)
                 continue
 
@@ -147,7 +143,7 @@ class PluginPyLoad(object):
                 post = {'name': "'%s'" % entry['title'].encode("ascii", "ignore"),
                         'links': str(urls),
                         'dest': dest,
-                        'session': self.session}
+                        'session': session}
 
                 pid = query_api(api, "addPackage", post).text
                 log.debug('added package pid: %s' % pid)
@@ -155,31 +151,21 @@ class PluginPyLoad(object):
                 if folder:
                     # set folder with api
                     data = {'folder': folder}
-                    query_api(api, "setPackageData", {'pid': pid, 'data': data, 'session': self.session})
+                    query_api(api, "setPackageData", {'pid': pid, 'data': data, 'session': session})
 
             except Exception as e:
                 entry.fail(str(e))
 
-    def check_login(self, task, config):
+    def get_session(self, config):
         url = config.get('api', self.DEFAULT_API)
 
-        if not self.session:
-            # Login
-            post = {'username': config['username'], 'password': config['password']}
-            result = query_api(url, "login", post)
-            response = result.json()
-            if not response:
-                raise PluginError('Login failed', log)
-            self.session = response.replace('"', '')
-        else:
-            try:
-                query_api(url, 'getServerVersion', {'session': self.session})
-            except HTTPError as e:
-                if e.response.status_code == 403:  # Forbidden
-                    self.session = None
-                    return self.check_login(task, config)
-                else:
-                    raise PluginError('HTTP Error %s' % e, log)
+        # Login
+        post = {'username': config['username'], 'password': config['password']}
+        result = query_api(url, "login", post)
+        response = result.json()
+        if not response:
+            raise plugin.PluginError('Login failed', log)
+        return response.replace('"', '')
 
 
 def query_api(url, method, post=None):
@@ -192,7 +178,10 @@ def query_api(url, method, post=None):
         return response
     except RequestException as e:
         if e.response.status_code == 500:
-            raise PluginError('Internal API Error: <%s> <%s> <%s>' % (method, url, post), log)
+            raise plugin.PluginError('Internal API Error: <%s> <%s> <%s>' % (method, url, post), log)
         raise
 
-register_plugin(PluginPyLoad, 'pyload', api_ver=2)
+
+@event('plugin.register')
+def register_plugin():
+    plugin.register(PluginPyLoad, 'pyload', api_ver=2)
